@@ -105,9 +105,12 @@
 
     Updated by      Richard Gooch   6-DEC-1999: Change directory to devfs FS.
 
-    Last updated by Richard Gooch   9-DEC-1999: Support compiling with 2.2.x
+    Updated by      Richard Gooch   9-DEC-1999: Support compiling with 2.2.x
   kernels.
 
+    Last updated by Richard Gooch   15-DEC-1999: Added compatibility entries
+  for miscellaneous character devices.
+
 
 */
 #include <unistd.h>
@@ -141,7 +144,7 @@
 #endif
 
 
-#define VERSION "1.2.13"
+#define VERSION "1.2.14"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS (6 + 1)
 
@@ -1089,6 +1092,8 @@ static void action_compat (const struct devfsd_notify_struct *info,
 	    sprintf (compat_buf, "%sjs%d", type, index);
 	    compat_name = compat_buf;
 	}
+	else if (strncmp (info->devname, "misc/", 5) == 0)
+	    compat_name = info->devname + 5;
 	break;
       case AC_MKNEWCOMPAT:
       case AC_RMNEWCOMPAT:
